summaryrefslogtreecommitdiffstats
path: root/libtdepim/kmailcompletion.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/kmailcompletion.cpp')
-rw-r--r--libtdepim/kmailcompletion.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/libtdepim/kmailcompletion.cpp b/libtdepim/kmailcompletion.cpp
index d7fcc8ce..84640cb1 100644
--- a/libtdepim/kmailcompletion.cpp
+++ b/libtdepim/kmailcompletion.cpp
@@ -34,12 +34,12 @@ KMailCompletion::KMailCompletion()
void KMailCompletion::clear()
{
m_keyMap.clear();
- KCompletion::clear();
+ TDECompletion::clear();
}
TQString KMailCompletion::makeCompletion( const TQString &string )
{
- TQString match = KCompletion::makeCompletion( string );
+ TQString match = TDECompletion::makeCompletion( string );
// this should be in postProcessMatch, but postProcessMatch is const and will not allow nextMatch
if ( !match.isEmpty() ){
@@ -79,7 +79,7 @@ void KMailCompletion::addItemWithKeys( const TQString& email, int weight, const
TQStringList &emailList = m_keyMap[ (*it) ]; //lookup email-list for given keyword
if ( emailList.find( email ) == emailList.end() ) //add email if not there
emailList.append( email );
- addItem( (*it),weight ); //inform KCompletion about keyword
+ addItem( (*it),weight ); //inform TDECompletion about keyword
}
}
@@ -89,7 +89,7 @@ void KMailCompletion::postProcessMatches( TQStringList * pMatches )const
if ( pMatches->isEmpty() )
return;
//KCompletion has found the keywords for us, we can now map them to mail-addr
TQMap< TQString, bool > mailAddrDistinct; //TODO replace with TQSet in KDE4
for ( TQStringList::ConstIterator sit ( pMatches->begin() ), sEnd( pMatches->end() ); sit != sEnd; ++sit ) {
const TQStringList &mailAddr = m_keyMap[ (*sit) ]; //get all mailAddr for this keyword
@@ -89,7 +89,7 @@ void KMailCompletion::postProcessMatches( TQStringList * pMatches )const
if ( pMatches->isEmpty() )
return;
- //KCompletion has found the keywords for us, we can now map them to mail-addr
+ //TDECompletion has found the keywords for us, we can now map them to mail-addr
TQMap< TQString, bool > mailAddrDistinct; //TODO replace with TQSet in KDE4
for ( TQStringList::ConstIterator sit ( pMatches->begin() ), sEnd( pMatches->end() ); sit != sEnd; ++sit ) {